import { useState, useEffect, useRef, useCallback, useReducer } from 'react';

function useDebounce(value, delay) {
  if (delay === void 0) {
    delay = 500;
  }

  var _useState = useState(value),
      debouncedValue = _useState[0],
      setDebouncedValue = _useState[1];

  useEffect(function () {
    var handler = setTimeout(function () {
      setDebouncedValue(value);
    }, delay);
    return function () {
      return clearTimeout(handler);
    };
  }, [delay, value]);
  return debouncedValue;
}

function useIsMounted() {
  var mountedRef = useRef(false);
  var isMounted = useCallback(function () {
    return mountedRef.current;
  }, []);
  useEffect(function () {
    mountedRef.current = true;
    return function () {
      mountedRef.current = false;
    };
  }, []);
  return isMounted;
}

function useSafeState(initialState) {
  var isMounted = useIsMounted();

  var _useState = useState(initialState),
      state = _useState[0],
      setState = _useState[1];

  var safeSetState = useCallback(function (value) {
    if (isMounted()) {
      setState(value);
    }
  }, [isMounted]);
  return [state, safeSetState];
}

function usePrevious(value) {
  // Store current value in ref
  var ref = useRef();
  useEffect(function () {
    // Update the value if it changes
    ref.current = value;
  }, [value]); // return the previous value

  return ref.current;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function useLegacyState(initialState) {
  return useReducer(function (state, update) {
    return _extends({}, state, update);
  }, initialState);
}

export { useDebounce, useIsMounted, useLegacyState, usePrevious, useSafeState };
//# sourceMappingURL=react-use-custom-hooks.esm.js.map
